@@ -3,7 +3,8 @@ from qiskit.quantum_info import Statevector
 from qiskit.visualization import plot_histogram
 import matplotlib.pyplot as plt
 from math import log
-from . import _states, _circs, _hists, _master_show, _show_plt
+
+from . import _states, _circs, _hists, _master_show, _show_plt, _round_to
 from ._src import _get_path
 
 _circ_count = 0
@@ -11,7 +12,7 @@ _state_count = 0
 _hist_count = 0
 
 def _message(msg):
-    print(f"UC_Quantum_Lab: {msg}")
+    print(f"From UC_Quantum_Lab: {msg}")
 
 def _show_at_exit():
     global _show_plt
@@ -53,9 +54,9 @@ def state(circuit:QuantumCircuit, show:bool=True)->list[complex]:
     for i in range(len(_state)):
         val = _state[i]
         if type(val) == complex:
-            val = round(val.real, 10) + round(val.imag, 10) *1j
+            val = round(val.real, _round_to) + round(val.imag, _round_to) *1j
         else:
-            val = round(val, 10)
+            val = round(val, _round_to)
         _data[_options[i]] = str(val).replace("(", "").replace(")", "")
 
     if show and _master_show:
